==> zoneminder_1.22.3.orig.tar.gz: ZoneMinder-1.22.3/src/zm_file_camera.h <==
//
// ZoneMinder File Camera Class Interface, $Date: 2006/01/17 10:56:30 $, $Revision: 1.2 $
// Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 

#ifndef ZM_FILE_CAMERA_H
#define ZM_FILE_CAMERA_H

#include "zm_camera.h"
#include "zm_buffer.h"
#include "zm_regexp.h"

//
// Class representing 'file' cameras, i.e. those which are
// accessed over a network connection.
//
class FileCamera : public Camera
{
protected:
	char path[PATH_MAX];

public:
	FileCamera( const char *p_path, int p_width, int p_height, int p_palette, int p_brightness, int p_contrast, int p_hue, int p_colour, bool p_capture=true );
	~FileCamera();

	const char *Path() const { return( path ); }

	void Initialise();
	void Terminate();
	int PreCapture();
	int PostCapture( Image &image );
};

#endif // ZM_FILE_CAMERA_H

==> zoneminder_1.24.4.orig.tar.gz: ZoneMinder-1.24.4/src/zm_file_camera.h <==
//
// ZoneMinder File Camera Class Interface, $Date: 2009-01-28 09:48:06 +0000 (Wed, 28 Jan 2009) $, $Revision: 2724 $
// Copyright (C) 2001-2008 Philip Coombes
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 

#ifndef ZM_FILE_CAMERA_H
#define ZM_FILE_CAMERA_H

#include "zm_camera.h"
#include "zm_buffer.h"
#include "zm_regexp.h"

//
// Class representing 'file' cameras, i.e. those which are
// accessed over a network connection.
//
class FileCamera : public Camera
{
protected:
	char path[PATH_MAX];

public:
	FileCamera( int p_id, const char *p_path, int p_width, int p_height, int p_palette, int p_brightness, int p_contrast, int p_hue, int p_colour, bool p_capture );
	~FileCamera();

	const char *Path() const { return( path ); }

	void Initialise();
	void Terminate();
	int PreCapture();
	int Capture( Image &image );
	int PostCapture();
};

#endif // ZM_FILE_CAMERA_H
